@@ -15,7 +15,19 @@ class InvalidVerseError(Exception):
         if not self.message:
             if self.book and self.chapter and self.verse:
                 self.message = f"{self.book.title} {self.chapter}:{self.verse} is not a valid verse."
-            else:
+            elif self.verse_id:
                 self.message = f"{self.verse_id} is not a valid verse."
 
         super(InvalidVerseError, self).__init__(self.message)
+
+
+class InvalidBibleParserError(Exception):
+    """Raised when the Bible parser is not valid."""
+
+
+class MissingVerseFileError(Exception):
+    """Raised when the verse file for a given version is not found."""
+
+
+class MissingBookFileError(Exception):
+    """Raised when the book file for a given version is not found."""
