@@ -38,6 +38,41 @@ def test_format_scripture_references_sorting(
     assert reference == formatted_reference
 
 
+def test_format_scripture_reference_single_verse(verse_id):
+    # Given a single verse id
+    book, chapter, verse = bible.get_book_chapter_verse(verse_id)
+
+    # When we format the reference for it for different versions
+    short_kjv_reference = bible.format_single_reference(
+        book, chapter, verse, chapter, verse, version=bible.Version.KING_JAMES
+    )
+    short_asv_reference = bible.format_single_reference(
+        book, chapter, verse, chapter, verse, version=bible.Version.AMERICAN_STANDARD
+    )
+    long_kjv_reference = bible.format_single_reference(
+        book,
+        chapter,
+        verse,
+        chapter,
+        verse,
+        version=bible.Version.KING_JAMES,
+        full_title=True,
+    )
+    long_asv_reference = bible.format_single_reference(
+        book,
+        chapter,
+        verse,
+        chapter,
+        verse,
+        version=bible.Version.AMERICAN_STANDARD,
+        full_title=True,
+    )
+
+    # Then the short references should match, but the long ones should be different.
+    assert short_kjv_reference == short_asv_reference
+    assert long_kjv_reference != long_asv_reference
+
+
 def test_format_scripture_text(verse_ids, html_scripture_text):
     # Given a list of verse ids
     # When we get the scripture text for those verse ids
@@ -82,7 +117,7 @@ def test_get_verse_text_invalid(invalid_verse_id):
     # Given an invalid verse id
     # When attempting to get the verse text for that verse id
     # Then an error is raised.
-    with pytest.raises(bible.InvalidVerseError):
+    with pytest.raises(bible.InvalidVerseError, match="1100100 is not a valid verse."):
         bible.get_verse_text(invalid_verse_id)
 
 
