@@ -25,7 +25,10 @@ def test_get_verse_id_invalid_verse(book, chapter, invalid_verse):
     # Given a book of the Bible, a chapter number, and a verse number that is not valid
 
     # When the get_verse_id() function is called, Then an exception is raised.
-    with pytest.raises(bible.InvalidVerseError):
+    with pytest.raises(
+        bible.InvalidVerseError,
+        match="Genesis 1:100 is not a valid Bible verse. Valid verses for that book and chapter are 1-31",
+    ):
         bible.verses.get_verse_id(book, chapter, invalid_verse)
 
 
@@ -61,7 +64,7 @@ def test_get_book_chapter_verse_invalid(invalid_verse_id):
     # Given an invalid verse id
     # When attempting to get the book, chapter, and verse
     # Then an error is raised.
-    with pytest.raises(bible.InvalidVerseError):
+    with pytest.raises(bible.InvalidVerseError, match="1100100 is not a valid verse."):
         bible.get_book_chapter_verse(invalid_verse_id)
 
 
